# User
Extends or inherits `AbstractBaseUser` and `PermissionsMixin` both from `django.contrib.auth.models` module.

## [Properties](properties.md)
Contains a list of additional(other than the ones present in its super classes) properties.

## [Methods](methods.md)
Contains a list of additional(other than the ones present in its super classes) methods.